<template>
  <div class="returned">
    <div class="filter">
      <div class="filter-card">
        <CommonSearch
            :show-add="false"
            :show-download="false"
            :amount-view="false"
            :show-action-btn="false"
            placeholder="请输入采购单/供应商名称等"
            @searchClick="onFilterSearch"
        />
      </div>
    </div>

    <div class="body">
      <div class="body-card">
       <div class="list-view">
         <TableCommonView
             class="content-table"
             ref="tableListRef"
             :table-list="tableList"
             @selCommonClick="selCommonClick"
             @selTableCol="selTableCol"
         >
           <template slot="tableButton">
             <el-table-column align="center" label="状态" width="120">
               <template slot-scope="scope">
                 {{ getReturnedStatus(scope.row.member_name) }}
               </template>
             </el-table-column>
             <el-table-column align="center" label="操作" width="120">
               <template slot-scope="scope">
                 <el-button  @click="confirmClick(scope.row)" type="text" size="small">确认发货</el-button>
               </template>
             </el-table-column>
           </template>
         </TableCommonView>
       </div>
        <div class="btn-pager">
          <PagerView class="page" :pager-options="pagerOptions" v-on="pagerEvents" />
        </div>
      </div>

    </div>

  
    <!-- 新建/编辑销售线索 -->
    <!-- <AddSalesLeadDialog v-if="editSalesLeadConfig.visible" :edit-rightContent-config="editSalesLeadConfig" /> -->
    <!-- 详情 -->
    <DetailSupplier v-if="commonDetail.visible" :common-detail="commonDetail" />
  </div>
</template>

<script>
import pageMixin from "@/components/makepager/pager/mixin/pageMixin"
import {
  getPurchaseList,getPurchaseInfo,submitPurchase, 
} from "@/api/purchaseManage/purchase";
import DetailSupplier from "@/views/purchaseManage/returned/DetailSupplier"
import { getDataByType } from "@/api/data";
export default {
  name: "SupplierManage",
  props: {},
  components: { DetailSupplier },
  mixins: [pageMixin],
  computed: {},
  data() {
    return {
      tableList: {}, // 列表
      selValueList: [],
      commonDetail: {
        visible: false,
        infomation: {}
      },
      search: '',
      returnedStatusList:getDataByType('returnedStatus'),
      tableColumn: [
        { label: "退货单编号", prop: "number", min: 190, isCommonClick: true ,default:true},
        { label: "采购单编号", prop: "name", min: 130, isCommonClick: true},
        { label: "单据类型", prop: "contact_name", min: 130 },
        { label: "供应商名称", prop: "contact_phone", min: 130 },
        { label: "退货仓库", prop: "sales_resources", min: 130 },
        { label: "退货理由", prop: "province", min: 180 },
        { label: "经办人", prop: "city", min: 130 },
        { label: "制单人", prop: "member_name", min: 130 },
        { label: "退货日期", prop: "member_name", min: 150 },
        // { label: "状态", prop: "member_name", min: 110 }
      ],
      showCol: ['退货单编号', '采购单编号', '单据类型', '供应商名称', '退货仓库', '退货理由', '退货日期']
    }
  },
  created() {
    this.setTable()
    this.getData()
  },
  methods: {
    getReturnedStatus(val) {
      if (val) {
        for (let i in this.returnedStatusList) {
          if (this.returnedStatusList[i].id == val) {
            return this.returnedStatusList[i].name;
          }
        }
      } else {
        return "--";
      }
    },
    setColumnVisible(showCol){
      return  this.tableColumn.map(ele=>{
        return {
          ...ele,
          isShowColumn:showCol.includes(ele.label)
        }
      })
    },
    setTable() {
      this.tableList = {
        tableInfomation: [],
        selectIndex: true,
        showcol: this.showCol,
        allcol: [],
        tableColumn:this.setColumnVisible(this.showCol)
      }
      this.tableList.allcol = this.tableList.tableColumn.filter(ele=>!ele.default).map(ele=>ele.label);
    },
    selTableCol(val) {
      this.showcol = val;
      this.tableList.tableColumn = this.setColumnVisible(val);
    },
    // 请求数据
    async getData() {
      await getPurchaseList({
        keyword: this.search,
        page: this.pagerOptions.currPage,
        pageSize: this.pagerOptions.pageSize
      })
        .then((res) => {
          const list = res.data.data.list
          this.tableList.tableInfomation = list || []
          this.pagerOptions.totalCount = res.data.data.total
        })
        .catch((err) => {
          console.log(err)
        })
    },
    onFilterSearch(searchText){
      this.search = searchText ?? ''
      this.pagerOptions.currPage = 1
      this.getData()
    },
   
    // 确认发货
    confirmClick() {
        this.$confirm("是否确认发货?", "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        })
          .then(() => {
            console.log("dddd")
            submitPurchase({ ids: this.selValueList }).then((response) => {
              if (response.code === 200) {
                this.$message.success("确认发货成功")
                this.getData()
              } else {
                this.$message.warning("确认发货失败")
              }
            })
          })
          .catch(() => {})
    },
    
    // 详情
    selCommonClick(row) {
      console.log(row)
      getPurchaseInfo({id:row.ID}).then((res) => {
        if (res.code == 200) {
          this.commonDetail.visible = true
          this.commonDetail.infomation = { 
            productList:res.data.productList,
            ...res.data.purchase
           }
        }else{
          this.$message.error(res.msg?res.msg+',':''+'获取信息失败！')
        }
      })
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
.returned{
  height: 100%;
  overflow: hidden;
  background-color: transparent;
  .filter{
    height: 80px;
    display: flex;
    align-items: center;
    padding: 12px 20px 0 20px;
    &-card{
      height: 80px;
      display: flex;
      align-items: center;
      box-sizing: border-box;
      padding: 10px 20px;
      flex: 1;
      border-radius: 12px;
      background-color: #fff;
    }
  }
  .body{
    box-sizing: border-box;
    padding: 10px 20px;
    border-radius: 12px;
    height: calc(100% - 92px);
    &-card {
      background-color: #fff;
      border-radius: 12px;
      height: 100%;
      overflow: hidden;
    }
    .list-view {
      height: calc(100% - 60px);
      overflow: hidden;
    }
    .btn-pager {
      display: flex;
      .page {
        margin-left: auto;
      }
    }
  }
}
</style>
